@@ -163,6 +163,10 @@ func (c *Conn) Handle() {
 	defer c.tr.Finish()
 	c.tr.Debugf("Connected, mode: %s", c.mode)
 
+	// Set the first deadline, which covers possibly the TLS handshake and
+	// then our initial greeting.
+	c.conn.SetDeadline(time.Now().Add(c.commandTimeout))
+
 	if tc, ok := c.conn.(*tls.Conn); ok {
 		// For TLS connections, complete the handshake and get the state, so
 		// it can be used when we say hello below.
@@ -739,8 +743,7 @@ func (c *Conn) runPostDataHook(data []byte) ([]byte, bool, error) {
 	defer tr.Finish()
 	tr.Debugf("running")
 
-	ctx, cancel := context.WithDeadline(context.Background(),
-		time.Now().Add(1*time.Minute))
+	ctx, cancel := context.WithTimeout(context.Background(), 1*time.Minute)
 	defer cancel()
 	cmd := exec.CommandContext(ctx, c.postDataHook)
 	cmd.Stdin = bytes.NewReader(data)
